:title: API reference

API Reference
=============

.. automodule:: grafana_dashboards.grafana
    :members:
    :undoc-members:

.. automodule:: grafana_dashboards.grafana.datasource
    :members:
    :undoc-members:

.. automodule:: grafana_dashboards.grafana.dashboard
    :members:
    :undoc-members:
